module Issue1 exposing (suite)

import Bytes exposing (Bytes)
import Bytes.Decode as Decode
import Bytes.Encode as Encode
import Expect
import Flate
import LZ77
import Test exposing (..)


{-| Solution description

bit values were not correctly masked in the prefix table insert operation. This could cause overflow (e.g. -1 or stuff like that) that would give incorrect matches.

-}
suite =
    describe "issue 1"
        [ test "sanity check" <|
            \_ ->
                [ 1, 2, 3, 4, 5, 6 ]
                    |> encodeUnsignedInt8
                    |> Flate.deflateZlib
                    |> Flate.inflateZlib
                    |> Expect.notEqual Nothing
        , test "roundtrip" <|
            \_ ->
                data
                    |> Flate.deflateZlib
                    |> Flate.inflateZlib
                    |> Expect.notEqual Nothing
        , test "vanilla roundtrip lz77" <|
            \_ ->
                let
                    raw =
                        rawData
                            |> List.take n
                            |> List.drop 8

                    n =
                        -- 138
                        138

                    expected =
                        raw
                            |> List.take n
                            |> Just

                    given =
                        raw
                            |> List.take n
                            |> encodeUnsignedInt8
                            |> LZ77.encode
                            |> LZ77.decode
                            |> (\b -> Decode.decode (unsignedInt8List (Bytes.width b)) b)
                in
                given
                    |> Expect.equal expected
        , test "vanilla roundtrip" <|
            \_ ->
                data
                    |> Flate.deflate
                    |> Flate.inflate
                    |> Maybe.andThen (\b -> Decode.decode (unsignedInt8List (Bytes.width b)) b)
                    |> Expect.equal (Just rawData)
        ]


encodeUnsignedInt8 v =
    Encode.encode (Encode.sequence (List.map Encode.unsignedInt8 v))


data =
    Encode.encode (Encode.sequence (List.map Encode.unsignedInt8 rawData))


helpHelp ( n, accum ) =
    if n > 0 then
        Decode.map (\new -> Decode.Loop ( n - 1, new :: accum )) Decode.unsignedInt8

    else
        Decode.succeed (Decode.Done (List.reverse accum))


unsignedInt8List n =
    Decode.loop ( n, [] ) helpHelp


rawData =
    [ 0
    , 255
    , 0
    , 8
    , 255
    , 255
    , 8
    , 15
    , 255
    , 255
    , 16
    , 23
    , 255
    , 255
    , 24
    , 31
    , 255
    , 255
    , 32
    , 39
    , 255
    , 255
    , 41
    , 47
    , 255
    , 255
    , 49
    , 55
    , 255
    , 255
    , 57
    , 63
    , 255
    , 255
    , 65
    , 71
    , 255
    , 255
    , 74
    , 79
    , 255
    , 255
    , 82
    , 87
    , 255
    , 255
    , 90
    , 95
    , 255
    , 255
    , 98
    , 103
    , 255
    , 255
    , 106
    , 111
    , 255
    , 255
    , 115
    , 119
    , 255
    , 255
    , 123
    , 127
    , 255
    , 255
    , 131
    , 135
    , 255
    , 255
    , 139
    , 143
    , 255
    , 255
    , 148
    , 151
    , 255
    , 255
    , 156
    , 159
    , 255
    , 255
    , 164
    , 167
    , 255
    , 255
    , 172
    , 175
    , 255
    , 255
    , 180
    , 183
    , 255
    , 255
    , 189
    , 191
    , 255
    , 255
    , 197
    , 199
    , 255
    , 255
    , 205
    , 207
    , 255
    , 255
    , 213
    , 215
    , 255
    , 255
    , 222
    , 223
    , 255
    , 255
    , 230
    , 231
    , 255
    , 255
    , 238
    , 239
    , 255
    , 255
    , 246
    , 247
    , 255
    , 255
    , 255
    , 255
    , 255
    , 0
    , 238
    , 29
    , 7
    , 255
    , 255
    , 31
    , 8
    , 255
    , 255
    , 38
    , 15
    , 255
    , 255
    , 45
    , 23
    , 255
    , 255
    , 52
    , 31
    , 255
    , 255
    , 59
    , 39
    , 255
    , 255
    , 67
    , 47
    , 255
    , 255
    , 74
    , 55
    , 255
    , 255
    , 81
    , 63
    , 255
    , 255
    , 88
    , 71
    , 255
    , 255
    , 96
    , 79
    , 255
    , 255
    , 103
    , 87
    , 255
    , 255
    , 110
    , 95
    , 255
    , 255
    , 117
    , 103
    , 255
    , 255
    , 124
    , 111
    , 255
    , 255
    , 132
    , 119
    , 255
    , 255
    , 139
    , 127
    , 255
    , 255
    , 146
    , 135
    , 255
    , 255
    , 153
    , 143
    , 255
    , 255
    , 161
    , 151
    , 255
    , 255
    , 168
    , 159
    , 255
    , 255
    , 175
    , 167
    , 255
    , 255
    , 182
    , 175
    , 255
    , 255
    , 189
    , 183
    , 255
    , 255
    , 197
    , 191
    , 255
    , 255
    , 204
    , 199
    , 255
    , 255
    , 211
    , 207
    , 255
    , 255
    , 218
    , 215
    , 255
    , 255
    , 226
    , 223
    , 255
    , 255
    , 233
    , 231
    , 255
    , 255
    , 240
    , 239
    , 255
    , 255
    , 247
    , 247
    , 255
    , 0
    , 223
    , 55
    , 7
    , 255
    , 238
    , 59
    , 7
    , 255
    , 255
    , 63
    , 8
    , 255
    , 255
    , 69
    , 15
    , 255
    , 255
    , 75
    , 23
    , 255
    , 255
    , 81
    , 31
    , 255
    , 255
    , 87
    , 39
    , 255
    , 255
    , 93
    , 47
    , 255
    , 255
    , 100
    , 55
    , 255
    , 255
    , 106
    , 63
    , 255
    , 255
    , 112
    , 71
    , 255
    , 255
    , 118
    , 79
    , 255
    , 255
    , 124
    , 87
    , 255
    , 255
    , 131
    , 95
    , 255
    , 255
    , 137
    , 103
    , 255
    , 255
    , 143
    , 111
    , 255
    , 255
    , 149
    , 119
    , 255
    , 255
    , 155
    , 127
    , 255
    , 255
    , 162
    , 135
    , 255
    , 255
    , 168
    , 143
    , 255
    , 255
    , 174
    , 151
    , 255
    , 255
    , 180
    , 159
    , 255
    , 255
    , 186
    , 167
    , 255
    , 255
    , 193
    , 175
    , 255
    , 255
    , 199
    , 183
    , 255
    , 255
    , 205
    , 191
    , 255
    , 255
    , 211
    , 199
    , 255
    , 255
    , 217
    , 207
    , 255
    , 255
    , 224
    , 215
    , 255
    , 255
    , 230
    , 223
    , 255
    , 255
    , 236
    , 231
    , 255
    , 255
    , 242
    , 239
    , 255
    , 0
    , 208
    , 77
    , 6
    , 255
    , 223
    , 83
    , 7
    , 255
    , 238
    , 88
    , 7
    , 255
    , 255
    , 95
    , 8
    , 255
    , 255
    , 100
    , 15
    , 255
    , 255
    , 105
    , 23
    , 255
    , 255
    , 110
    , 31
    , 255
    , 255
    , 115
    , 39
    , 255
    , 255
    , 120
    , 47
    , 255
    , 255
    , 125
    , 55
    , 255
    , 255
    , 131
    , 63
    , 255
    , 255
    , 136
    , 71
    , 255
    , 255
    , 141
    , 79
    , 255
    , 255
    , 146
    , 87
    , 255
    , 255
    , 151
    , 95
    , 255
    , 255
    , 156
    , 103
    , 255
    , 255
    , 162
    , 111
    , 255
    , 255
    , 167
    , 119
    , 255
    , 255
    , 172
    , 127
    , 255
    , 255
    , 177
    , 135
    , 255
    , 255
    , 182
    , 143
    , 255
    , 255
    , 187
    , 151
    , 255
    , 255
    , 193
    , 159
    , 255
    , 255
    , 198
    , 167
    , 255
    , 255
    , 203
    , 175
    , 255
    , 255
    , 208
    , 183
    , 255
    , 255
    , 213
    , 191
    , 255
    , 255
    , 218
    , 199
    , 255
    , 255
    , 224
    , 207
    , 255
    , 255
    , 229
    , 215
    , 255
    , 255
    , 234
    , 223
    , 255
    , 255
    , 239
    , 231
    , 255
    , 0
    , 193
    , 96
    , 5
    , 255
    , 208
    , 103
    , 5
    , 255
    , 223
    , 111
    , 6
    , 255
    , 238
    , 118
    , 6
    , 255
    , 255
    , 127
    , 7
    , 255
    , 255
    , 131
    , 15
    , 255
    , 255
    , 135
    , 23
    , 255
    , 255
    , 139
    , 31
    , 255
    , 255
    , 143
    , 39
    , 255
    , 255
    , 147
    , 46
    , 255
    , 255
    , 151
    , 55
    , 255
    , 255
    , 155
    , 63
    , 255
    , 255
    , 160
    , 71
    , 255
    , 255
    , 164
    , 78
    , 255
    , 255
    , 168
    , 87
    , 255
    , 255
    , 172
    , 95
    , 255
    , 255
    , 176
    , 103
    , 255
    , 255
    , 180
    , 110
    , 255
    , 255
    , 184
    , 119
    , 255
    , 255
    , 188
    , 127
    , 255
    , 255
    , 193
    , 135
    , 255
    , 255
    , 197
    , 142
    , 255
    , 255
    , 201
    , 151
    , 255
    , 255
    , 205
    , 159
    , 255
    , 255
    , 209
    , 166
    , 255
    , 255
    , 213
    , 174
    , 255
    , 255
    , 217
    , 183
    , 255
    , 255
    , 221
    , 191
    , 255
    , 255
    , 226
    , 198
    , 255
    , 255
    , 230
    , 206
    , 255
    , 255
    , 234
    , 215
    , 255
    , 255
    , 238
    , 223
    , 255
    , 0
    , 179
    , 111
    , 4
    , 255
    , 193
    , 120
    , 5
    , 255
    , 208
    , 129
    , 5
    , 255
    , 223
    , 139
    , 6
    , 255
    , 238
    , 148
    , 6
    , 255
    , 255
    , 159
    , 7
    , 255
    , 255
    , 162
    , 15
    , 255
    , 255
    , 165
    , 23
    , 255
    , 255
    , 168
    , 31
    , 255
    , 255
    , 171
    , 39
    , 255
    , 255
    , 174
    , 46
    , 255
    , 255
    , 177
    , 55
    , 255
    , 255
    , 180
    , 63
    , 255
    , 255
    , 183
    , 71
    , 255
    , 255
    , 186
    , 78
    , 255
    , 255
    , 189
    , 87
    , 255
    , 255
    , 193
    , 95
    , 255
    , 255
    , 196
    , 103
    , 255
    , 255
    , 199
    , 110
    , 255
    , 255
    , 202
    , 119
    , 255
    , 255
    , 205
    , 127
    , 255
    , 255
    , 208
    , 135
    , 255
    , 255
    , 211
    , 142
    , 255
    , 255
    , 214
    , 151
    , 255
    , 255
    , 217
    , 159
    , 255
    , 255
    , 220
    , 166
    , 255
    , 255
    , 224
    , 174
    , 255
    , 255
    , 227
    , 183
    , 255
    , 255
    , 230
    , 191
    , 255
    , 255
    , 233
    , 198
    , 255
    , 255
    , 236
    , 206
    , 255
    , 255
    , 239
    , 215
    , 255
    , 0
    , 165
    , 124
    , 4
    , 255
    , 179
    , 134
    , 4
    , 255
    , 193
    , 144
    , 5
    , 255
    , 208
    , 155
    , 5
    , 255
    , 223
    , 167
    , 6
    , 255
    , 238
    , 178
    , 6
    , 255
    , 255
    , 191
    , 7
    , 255
    , 255
    , 193
    , 15
    , 255
    , 255
    , 195
    , 23
    , 255
    , 255
    , 197
    , 31
    , 255
    , 255
    , 199
    , 39
    , 255
    , 255
    , 201
    , 46
    , 255
    , 255
    , 203
    , 55
    , 255
    , 255
    , 205
    , 63
    , 255
    , 255
    , 207
    , 71
    , 255
    , 255
    , 209
    , 78
    , 255
    , 255
    , 211
    , 87
    , 255
    , 255
    , 213
    , 95
    , 255
    , 255
    , 215
    , 103
    , 255
    , 255
    , 217
    , 110
    , 255
    , 255
    , 219
    , 119
    , 255
    , 255
    , 221
    , 127
    , 255
    , 255
    , 224
    , 135
    , 255
    , 255
    , 226
    , 142
    , 255
    , 255
    , 228
    , 151
    , 255
    , 255
    , 230
    , 159
    , 255
    , 255
    , 232
    , 166
    , 255
    , 255
    , 234
    , 174
    , 255
    , 255
    , 236
    , 183
    , 255
    , 255
    , 238
    , 191
    , 255
    , 255
    , 240
    , 198
    , 255
    , 255
    , 242
    , 206
    , 255
    , 0
    , 152
    , 133
    , 4
    , 255
    , 165
    , 145
    , 4
    , 255
    , 179
    , 156
    , 4
    , 255
    , 193
    , 169
    , 5
    , 255
    , 208
    , 181
    , 5
    , 255
    , 223
    , 195
    , 6
    , 255
    , 238
    , 208
    , 6
    , 255
    , 255
    , 223
    , 7
    , 255
    , 255
    , 224
    , 15
    , 255
    , 255
    , 225
    , 23
    , 255
    , 255
    , 226
    , 31
    , 255
    , 255
    , 227
    , 39
    , 255
    , 255
    , 228
    , 46
    , 255
    , 255
    , 229
    , 55
    , 255
    , 255
    , 230
    , 63
    , 255
    , 255
    , 231
    , 71
    , 255
    , 255
    , 232
    , 78
    , 255
    , 255
    , 233
    , 87
    , 255
    , 255
    , 234
    , 95
    , 255
    , 255
    , 235
    , 103
    , 255
    , 255
    , 236
    , 110
    , 255
    , 255
    , 237
    , 119
    , 255
    , 255
    , 238
    , 127
    , 255
    , 255
    , 239
    , 135
    , 255
    , 255
    , 240
    , 142
    , 255
    , 255
    , 241
    , 151
    , 255
    , 255
    , 242
    , 159
    , 255
    , 255
    , 243
    , 166
    , 255
    , 255
    , 244
    , 174
    , 255
    , 255
    , 245
    , 183
    , 255
    , 255
    , 246
    , 191
    , 255
    , 255
    , 247
    , 198
    , 255
    , 0
    , 140
    , 140
    , 3
    , 255
    , 152
    , 152
    , 3
    , 255
    , 165
    , 165
    , 3
    , 255
    , 179
    , 179
    , 4
    , 255
    , 193
    , 193
    , 4
    , 255
    , 208
    , 208
    , 4
    , 255
    , 223
    , 223
    , 5
    , 255
    , 238
    , 238
    , 5
    , 255
    , 255
    , 255
    , 6
    , 255
    , 255
    , 255
    , 14
    , 255
    , 255
    , 255
    , 22
    , 255
    , 255
    , 255
    , 30
    , 255
    , 255
    , 255
    , 38
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 255
    , 255
    , 94
    , 255
    , 255
    , 255
    , 102
    , 255
    , 255
    , 255
    , 110
    , 255
    , 255
    , 255
    , 118
    , 255
    , 255
    , 255
    , 126
    , 255
    , 255
    , 255
    , 134
    , 255
    , 255
    , 255
    , 142
    , 255
    , 255
    , 255
    , 150
    , 255
    , 255
    , 255
    , 158
    , 255
    , 255
    , 255
    , 166
    , 255
    , 255
    , 255
    , 174
    , 255
    , 255
    , 255
    , 182
    , 255
    , 255
    , 255
    , 190
    , 255
    , 0
    , 112
    , 128
    , 3
    , 255
    , 123
    , 140
    , 3
    , 255
    , 134
    , 152
    , 3
    , 255
    , 145
    , 165
    , 3
    , 255
    , 157
    , 179
    , 4
    , 255
    , 169
    , 193
    , 4
    , 255
    , 182
    , 208
    , 4
    , 255
    , 196
    , 223
    , 5
    , 255
    , 209
    , 238
    , 5
    , 255
    , 224
    , 255
    , 6
    , 255
    , 225
    , 255
    , 14
    , 255
    , 226
    , 255
    , 22
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 235
    , 255
    , 94
    , 255
    , 236
    , 255
    , 102
    , 255
    , 236
    , 255
    , 110
    , 255
    , 238
    , 255
    , 118
    , 255
    , 239
    , 255
    , 126
    , 255
    , 240
    , 255
    , 134
    , 255
    , 240
    , 255
    , 142
    , 255
    , 242
    , 255
    , 150
    , 255
    , 243
    , 255
    , 158
    , 255
    , 243
    , 255
    , 166
    , 255
    , 244
    , 255
    , 174
    , 255
    , 246
    , 255
    , 182
    , 255
    , 0
    , 88
    , 117
    , 2
    , 255
    , 96
    , 128
    , 3
    , 255
    , 105
    , 140
    , 3
    , 255
    , 115
    , 152
    , 3
    , 255
    , 124
    , 165
    , 3
    , 255
    , 135
    , 179
    , 4
    , 255
    , 145
    , 193
    , 4
    , 255
    , 156
    , 208
    , 4
    , 255
    , 168
    , 223
    , 5
    , 255
    , 179
    , 238
    , 5
    , 255
    , 192
    , 255
    , 6
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 200
    , 255
    , 38
    , 255
    , 202
    , 255
    , 46
    , 255
    , 204
    , 255
    , 54
    , 255
    , 206
    , 255
    , 62
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 214
    , 255
    , 94
    , 255
    , 216
    , 255
    , 102
    , 255
    , 218
    , 255
    , 110
    , 255
    , 220
    , 255
    , 118
    , 255
    , 222
    , 255
    , 126
    , 255
    , 224
    , 255
    , 134
    , 255
    , 226
    , 255
    , 142
    , 255
    , 228
    , 255
    , 150
    , 255
    , 230
    , 255
    , 158
    , 255
    , 232
    , 255
    , 166
    , 255
    , 234
    , 255
    , 174
    , 255
    , 0
    , 66
    , 106
    , 2
    , 255
    , 73
    , 117
    , 2
    , 255
    , 80
    , 128
    , 2
    , 255
    , 88
    , 140
    , 2
    , 255
    , 95
    , 152
    , 2
    , 255
    , 104
    , 165
    , 3
    , 255
    , 112
    , 179
    , 3
    , 255
    , 121
    , 193
    , 3
    , 255
    , 130
    , 208
    , 4
    , 255
    , 140
    , 223
    , 4
    , 255
    , 149
    , 238
    , 4
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 166
    , 255
    , 21
    , 255
    , 169
    , 255
    , 29
    , 255
    , 172
    , 255
    , 37
    , 255
    , 175
    , 255
    , 45
    , 255
    , 178
    , 255
    , 53
    , 255
    , 181
    , 255
    , 61
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 190
    , 255
    , 85
    , 255
    , 193
    , 255
    , 93
    , 255
    , 196
    , 255
    , 101
    , 255
    , 199
    , 255
    , 109
    , 255
    , 202
    , 255
    , 117
    , 255
    , 205
    , 255
    , 125
    , 255
    , 209
    , 255
    , 134
    , 255
    , 212
    , 255
    , 142
    , 255
    , 215
    , 255
    , 150
    , 255
    , 218
    , 255
    , 158
    , 255
    , 221
    , 255
    , 166
    , 255
    , 0
    , 48
    , 95
    , 1
    , 255
    , 53
    , 106
    , 2
    , 255
    , 58
    , 117
    , 2
    , 255
    , 64
    , 128
    , 2
    , 255
    , 70
    , 140
    , 2
    , 255
    , 76
    , 152
    , 2
    , 255
    , 83
    , 165
    , 3
    , 255
    , 90
    , 179
    , 3
    , 255
    , 97
    , 193
    , 3
    , 255
    , 104
    , 208
    , 4
    , 255
    , 112
    , 223
    , 4
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 132
    , 255
    , 13
    , 255
    , 136
    , 255
    , 21
    , 255
    , 140
    , 255
    , 29
    , 255
    , 144
    , 255
    , 37
    , 255
    , 148
    , 255
    , 45
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 164
    , 255
    , 77
    , 255
    , 168
    , 255
    , 85
    , 255
    , 173
    , 255
    , 93
    , 255
    , 177
    , 255
    , 101
    , 255
    , 181
    , 255
    , 109
    , 255
    , 185
    , 255
    , 117
    , 255
    , 189
    , 255
    , 125
    , 255
    , 193
    , 255
    , 134
    , 255
    , 197
    , 255
    , 142
    , 255
    , 201
    , 255
    , 150
    , 255
    , 205
    , 255
    , 158
    , 255
    , 0
    , 32
    , 85
    , 1
    , 255
    , 36
    , 95
    , 1
    , 255
    , 39
    , 106
    , 2
    , 255
    , 44
    , 117
    , 2
    , 255
    , 48
    , 128
    , 2
    , 255
    , 52
    , 140
    , 2
    , 255
    , 57
    , 152
    , 2
    , 255
    , 62
    , 165
    , 3
    , 255
    , 67
    , 179
    , 3
    , 255
    , 72
    , 193
    , 3
    , 255
    , 78
    , 208
    , 4
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 96
    , 255
    , 5
    , 255
    , 101
    , 255
    , 13
    , 255
    , 106
    , 255
    , 21
    , 255
    , 111
    , 255
    , 29
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 137
    , 255
    , 69
    , 255
    , 142
    , 255
    , 77
    , 255
    , 147
    , 255
    , 85
    , 255
    , 152
    , 255
    , 93
    , 255
    , 157
    , 255
    , 101
    , 255
    , 162
    , 255
    , 109
    , 255
    , 167
    , 255
    , 117
    , 255
    , 172
    , 255
    , 125
    , 255
    , 178
    , 255
    , 134
    , 255
    , 183
    , 255
    , 142
    , 255
    , 188
    , 255
    , 150
    , 255
    , 0
    , 19
    , 76
    , 1
    , 255
    , 21
    , 85
    , 1
    , 255
    , 24
    , 95
    , 1
    , 255
    , 26
    , 106
    , 2
    , 255
    , 29
    , 117
    , 2
    , 255
    , 32
    , 128
    , 2
    , 255
    , 35
    , 140
    , 2
    , 255
    , 38
    , 152
    , 2
    , 255
    , 41
    , 165
    , 3
    , 255
    , 45
    , 179
    , 3
    , 255
    , 48
    , 193
    , 3
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 59
    , 238
    , 4
    , 255
    , 64
    , 255
    , 5
    , 255
    , 70
    , 255
    , 13
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 107
    , 255
    , 61
    , 255
    , 113
    , 255
    , 69
    , 255
    , 119
    , 255
    , 77
    , 255
    , 125
    , 255
    , 85
    , 255
    , 131
    , 255
    , 93
    , 255
    , 137
    , 255
    , 101
    , 255
    , 144
    , 255
    , 109
    , 255
    , 150
    , 255
    , 117
    , 255
    , 156
    , 255
    , 125
    , 255
    , 162
    , 255
    , 134
    , 255
    , 168
    , 255
    , 142
    , 255
    , 0
    , 8
    , 67
    , 1
    , 255
    , 9
    , 76
    , 1
    , 255
    , 10
    , 85
    , 1
    , 255
    , 12
    , 95
    , 1
    , 255
    , 13
    , 106
    , 1
    , 255
    , 14
    , 117
    , 1
    , 255
    , 16
    , 128
    , 2
    , 255
    , 17
    , 140
    , 2
    , 255
    , 19
    , 152
    , 2
    , 255
    , 20
    , 165
    , 2
    , 255
    , 22
    , 179
    , 2
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 28
    , 223
    , 3
    , 255
    , 29
    , 238
    , 3
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 53
    , 255
    , 28
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 75
    , 255
    , 52
    , 255
    , 82
    , 255
    , 60
    , 255
    , 89
    , 255
    , 68
    , 255
    , 96
    , 255
    , 76
    , 255
    , 103
    , 255
    , 84
    , 255
    , 111
    , 255
    , 93
    , 255
    , 118
    , 255
    , 101
    , 255
    , 125
    , 255
    , 109
    , 255
    , 132
    , 255
    , 117
    , 255
    , 139
    , 255
    , 125
    , 255
    , 147
    , 255
    , 133
    , 255
    , 0
    , 0
    , 59
    , 0
    , 255
    , 1
    , 67
    , 0
    , 255
    , 1
    , 76
    , 0
    , 255
    , 1
    , 85
    , 0
    , 255
    , 1
    , 95
    , 0
    , 255
    , 1
    , 106
    , 0
    , 255
    , 1
    , 117
    , 0
    , 255
    , 2
    , 128
    , 0
    , 255
    , 2
    , 140
    , 0
    , 255
    , 2
    , 152
    , 0
    , 255
    , 2
    , 165
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 3
    , 208
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 12
    , 255
    , 8
    , 255
    , 20
    , 255
    , 16
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 44
    , 255
    , 41
    , 255
    , 52
    , 255
    , 49
    , 255
    , 60
    , 255
    , 57
    , 255
    , 68
    , 255
    , 65
    , 255
    , 76
    , 255
    , 74
    , 255
    , 84
    , 255
    , 82
    , 255
    , 93
    , 255
    , 90
    , 255
    , 101
    , 255
    , 98
    , 255
    , 109
    , 255
    , 106
    , 255
    , 117
    , 255
    , 115
    , 255
    , 125
    , 255
    , 123
    , 255
    , 0
    , 0
    , 52
    , 6
    , 255
    , 0
    , 59
    , 7
    , 255
    , 1
    , 67
    , 8
    , 255
    , 1
    , 76
    , 9
    , 255
    , 1
    , 85
    , 10
    , 255
    , 1
    , 95
    , 11
    , 255
    , 1
    , 106
    , 12
    , 255
    , 1
    , 117
    , 14
    , 255
    , 2
    , 128
    , 15
    , 255
    , 2
    , 140
    , 17
    , 255
    , 2
    , 152
    , 18
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 3
    , 238
    , 29
    , 255
    , 4
    , 255
    , 31
    , 255
    , 12
    , 255
    , 38
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 36
    , 255
    , 59
    , 255
    , 44
    , 255
    , 67
    , 255
    , 52
    , 255
    , 74
    , 255
    , 60
    , 255
    , 81
    , 255
    , 68
    , 255
    , 88
    , 255
    , 76
    , 255
    , 96
    , 255
    , 84
    , 255
    , 103
    , 255
    , 93
    , 255
    , 110
    , 255
    , 101
    , 255
    , 117
    , 255
    , 109
    , 255
    , 124
    , 255
    , 117
    , 255
    , 132
    , 255
    , 0
    , 0
    , 44
    , 11
    , 255
    , 0
    , 52
    , 12
    , 255
    , 0
    , 59
    , 14
    , 255
    , 0
    , 67
    , 16
    , 255
    , 0
    , 76
    , 18
    , 255
    , 1
    , 85
    , 21
    , 255
    , 1
    , 95
    , 23
    , 255
    , 1
    , 106
    , 26
    , 255
    , 1
    , 117
    , 28
    , 255
    , 1
    , 128
    , 31
    , 255
    , 1
    , 140
    , 34
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 2
    , 208
    , 51
    , 255
    , 2
    , 223
    , 55
    , 255
    , 2
    , 238
    , 59
    , 255
    , 3
    , 255
    , 63
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 27
    , 255
    , 81
    , 255
    , 35
    , 255
    , 87
    , 255
    , 43
    , 255
    , 93
    , 255
    , 51
    , 255
    , 100
    , 255
    , 59
    , 255
    , 106
    , 255
    , 68
    , 255
    , 112
    , 255
    , 76
    , 255
    , 118
    , 255
    , 84
    , 255
    , 124
    , 255
    , 92
    , 255
    , 131
    , 255
    , 100
    , 255
    , 137
    , 255
    , 108
    , 255
    , 143
    , 255
    , 0
    , 0
    , 38
    , 14
    , 255
    , 0
    , 44
    , 16
    , 255
    , 0
    , 52
    , 19
    , 255
    , 0
    , 59
    , 22
    , 255
    , 0
    , 67
    , 25
    , 255
    , 0
    , 76
    , 28
    , 255
    , 1
    , 85
    , 32
    , 255
    , 1
    , 95
    , 35
    , 255
    , 1
    , 106
    , 39
    , 255
    , 1
    , 117
    , 43
    , 255
    , 1
    , 128
    , 47
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 2
    , 179
    , 66
    , 255
    , 2
    , 193
    , 72
    , 255
    , 2
    , 208
    , 77
    , 255
    , 2
    , 223
    , 83
    , 255
    , 2
    , 238
    , 88
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 19
    , 255
    , 105
    , 255
    , 27
    , 255
    , 110
    , 255
    , 35
    , 255
    , 115
    , 255
    , 43
    , 255
    , 120
    , 255
    , 51
    , 255
    , 125
    , 255
    , 59
    , 255
    , 131
    , 255
    , 68
    , 255
    , 136
    , 255
    , 76
    , 255
    , 141
    , 255
    , 84
    , 255
    , 146
    , 255
    , 92
    , 255
    , 151
    , 255
    , 100
    , 255
    , 156
    , 255
    , 0
    , 0
    , 32
    , 15
    , 255
    , 0
    , 38
    , 19
    , 255
    , 0
    , 44
    , 22
    , 255
    , 0
    , 52
    , 25
    , 255
    , 0
    , 59
    , 29
    , 255
    , 0
    , 67
    , 33
    , 255
    , 0
    , 76
    , 38
    , 255
    , 1
    , 85
    , 42
    , 255
    , 1
    , 95
    , 47
    , 255
    , 1
    , 106
    , 52
    , 255
    , 1
    , 117
    , 58
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 1
    , 152
    , 76
    , 255
    , 1
    , 165
    , 82
    , 255
    , 2
    , 179
    , 89
    , 255
    , 2
    , 193
    , 96
    , 255
    , 2
    , 208
    , 103
    , 255
    , 2
    , 223
    , 111
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 11
    , 255
    , 131
    , 255
    , 19
    , 255
    , 135
    , 255
    , 27
    , 255
    , 139
    , 255
    , 35
    , 255
    , 143
    , 255
    , 43
    , 255
    , 147
    , 255
    , 51
    , 255
    , 151
    , 255
    , 59
    , 255
    , 155
    , 255
    , 68
    , 255
    , 160
    , 255
    , 76
    , 255
    , 164
    , 255
    , 84
    , 255
    , 168
    , 255
    , 92
    , 255
    , 172
    , 255
    , 0
    , 0
    , 26
    , 16
    , 255
    , 0
    , 32
    , 20
    , 255
    , 0
    , 38
    , 23
    , 255
    , 0
    , 44
    , 27
    , 255
    , 0
    , 52
    , 32
    , 255
    , 0
    , 59
    , 37
    , 255
    , 0
    , 67
    , 42
    , 255
    , 0
    , 76
    , 47
    , 255
    , 1
    , 85
    , 53
    , 255
    , 1
    , 95
    , 59
    , 255
    , 1
    , 106
    , 66
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 1
    , 152
    , 95
    , 255
    , 1
    , 165
    , 103
    , 255
    , 2
    , 179
    , 111
    , 255
    , 2
    , 193
    , 120
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 3
    , 255
    , 159
    , 255
    , 11
    , 255
    , 162
    , 255
    , 19
    , 255
    , 165
    , 255
    , 27
    , 255
    , 168
    , 255
    , 35
    , 255
    , 171
    , 255
    , 43
    , 255
    , 174
    , 255
    , 51
    , 255
    , 177
    , 255
    , 59
    , 255
    , 180
    , 255
    , 68
    , 255
    , 183
    , 255
    , 76
    , 255
    , 186
    , 255
    , 84
    , 255
    , 189
    , 255
    , 0
    , 0
    , 21
    , 16
    , 255
    , 0
    , 26
    , 19
    , 255
    , 0
    , 32
    , 24
    , 255
    , 0
    , 38
    , 28
    , 255
    , 0
    , 44
    , 33
    , 255
    , 0
    , 52
    , 38
    , 255
    , 0
    , 59
    , 44
    , 255
    , 0
    , 67
    , 50
    , 255
    , 0
    , 76
    , 57
    , 255
    , 0
    , 85
    , 64
    , 255
    , 0
    , 95
    , 71
    , 255
    , 0
    , 106
    , 79
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 1
    , 223
    , 167
    , 255
    , 1
    , 238
    , 178
    , 255
    , 2
    , 255
    , 191
    , 255
    , 10
    , 255
    , 193
    , 255
    , 18
    , 255
    , 195
    , 255
    , 26
    , 255
    , 197
    , 255
    , 34
    , 255
    , 199
    , 255
    , 42
    , 255
    , 201
    , 255
    , 50
    , 255
    , 203
    , 255
    , 59
    , 255
    , 205
    , 255
    , 67
    , 255
    , 207
    , 255
    , 75
    , 255
    , 209
    , 255
    , 0
    , 0
    , 16
    , 14
    , 255
    , 0
    , 21
    , 18
    , 255
    , 0
    , 26
    , 23
    , 255
    , 0
    , 32
    , 28
    , 255
    , 0
    , 38
    , 33
    , 255
    , 0
    , 44
    , 39
    , 255
    , 0
    , 52
    , 45
    , 255
    , 0
    , 59
    , 52
    , 255
    , 0
    , 67
    , 59
    , 255
    , 0
    , 76
    , 67
    , 255
    , 0
    , 85
    , 75
    , 255
    , 0
    , 95
    , 83
    , 255
    , 0
    , 106
    , 92
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 1
    , 193
    , 169
    , 255
    , 1
    , 208
    , 181
    , 255
    , 1
    , 223
    , 195
    , 255
    , 1
    , 238
    , 208
    , 255
    , 2
    , 255
    , 223
    , 255
    , 10
    , 255
    , 224
    , 255
    , 18
    , 255
    , 225
    , 255
    , 26
    , 255
    , 226
    , 255
    , 34
    , 255
    , 227
    , 255
    , 42
    , 255
    , 228
    , 255
    , 50
    , 255
    , 229
    , 255
    , 59
    , 255
    , 230
    , 255
    , 67
    , 255
    , 231
    , 255
    , 0
    , 0
    , 13
    , 13
    , 255
    , 0
    , 16
    , 16
    , 255
    , 0
    , 21
    , 21
    , 255
    , 0
    , 26
    , 26
    , 255
    , 0
    , 32
    , 32
    , 255
    , 0
    , 38
    , 38
    , 255
    , 0
    , 44
    , 44
    , 255
    , 0
    , 52
    , 52
    , 255
    , 0
    , 59
    , 59
    , 255
    , 0
    , 67
    , 67
    , 255
    , 0
    , 76
    , 76
    , 255
    , 0
    , 85
    , 85
    , 255
    , 0
    , 95
    , 95
    , 255
    , 0
    , 106
    , 106
    , 255
    , 0
    , 117
    , 117
    , 255
    , 1
    , 128
    , 128
    , 255
    , 1
    , 140
    , 140
    , 255
    , 1
    , 152
    , 152
    , 255
    , 1
    , 165
    , 165
    , 255
    , 1
    , 179
    , 179
    , 255
    , 1
    , 193
    , 193
    , 255
    , 1
    , 208
    , 208
    , 255
    , 1
    , 223
    , 223
    , 255
    , 1
    , 238
    , 238
    , 255
    , 2
    , 255
    , 255
    , 255
    , 10
    , 255
    , 255
    , 255
    , 18
    , 255
    , 255
    , 255
    , 26
    , 255
    , 255
    , 255
    , 34
    , 255
    , 255
    , 255
    , 42
    , 255
    , 255
    , 255
    , 50
    , 255
    , 255
    , 255
    , 59
    , 255
    , 255
    , 255
    , 0
    , 0
    , 8
    , 9
    , 255
    , 0
    , 11
    , 13
    , 255
    , 0
    , 14
    , 16
    , 255
    , 0
    , 18
    , 21
    , 255
    , 0
    , 23
    , 26
    , 255
    , 0
    , 28
    , 32
    , 255
    , 0
    , 33
    , 38
    , 255
    , 0
    , 39
    , 44
    , 255
    , 0
    , 45
    , 52
    , 255
    , 0
    , 52
    , 59
    , 255
    , 0
    , 59
    , 67
    , 255
    , 0
    , 67
    , 76
    , 255
    , 0
    , 75
    , 85
    , 255
    , 0
    , 84
    , 95
    , 255
    , 0
    , 93
    , 106
    , 255
    , 0
    , 102
    , 117
    , 255
    , 0
    , 112
    , 128
    , 255
    , 0
    , 123
    , 140
    , 255
    , 0
    , 134
    , 152
    , 255
    , 0
    , 145
    , 165
    , 255
    , 0
    , 157
    , 179
    , 255
    , 0
    , 169
    , 193
    , 255
    , 0
    , 182
    , 208
    , 255
    , 0
    , 196
    , 223
    , 255
    , 0
    , 209
    , 238
    , 255
    , 1
    , 224
    , 255
    , 255
    , 9
    , 225
    , 255
    , 255
    , 17
    , 226
    , 255
    , 255
    , 25
    , 227
    , 255
    , 255
    , 33
    , 228
    , 255
    , 255
    , 41
    , 228
    , 255
    , 255
    , 50
    , 230
    , 255
    , 255
    , 0
    , 0
    , 4
    , 6
    , 255
    , 0
    , 7
    , 9
    , 255
    , 0
    , 9
    , 13
    , 255
    , 0
    , 12
    , 16
    , 255
    , 0
    , 16
    , 21
    , 255
    , 0
    , 19
    , 26
    , 255
    , 0
    , 24
    , 32
    , 255
    , 0
    , 28
    , 38
    , 255
    , 0
    , 33
    , 44
    , 255
    , 0
    , 39
    , 52
    , 255
    , 0
    , 44
    , 59
    , 255
    , 0
    , 51
    , 67
    , 255
    , 0
    , 57
    , 76
    , 255
    , 0
    , 64
    , 85
    , 255
    , 0
    , 72
    , 95
    , 255
    , 0
    , 79
    , 106
    , 255
    , 0
    , 88
    , 117
    , 255
    , 0
    , 96
    , 128
    , 255
    , 0
    , 105
    , 140
    , 255
    , 0
    , 115
    , 152
    , 255
    , 0
    , 124
    , 165
    , 255
    , 0
    , 135
    , 179
    , 255
    , 0
    , 145
    , 193
    , 255
    , 0
    , 156
    , 208
    , 255
    , 0
    , 168
    , 223
    , 255
    , 0
    , 179
    , 238
    , 255
    , 1
    , 192
    , 255
    , 255
    , 9
    , 194
    , 255
    , 255
    , 17
    , 196
    , 255
    , 255
    , 25
    , 198
    , 255
    , 255
    , 33
    , 200
    , 255
    , 255
    , 41
    , 202
    , 255
    , 255
    , 0
    , 0
    , 2
    , 4
    , 255
    , 0
    , 4
    , 6
    , 255
    , 0
    , 5
    , 9
    , 255
    , 0
    , 8
    , 13
    , 255
    , 0
    , 10
    , 16
    , 255
    , 0
    , 13
    , 21
    , 255
    , 0
    , 16
    , 26
    , 255
    , 0
    , 20
    , 32
    , 255
    , 0
    , 23
    , 38
    , 255
    , 0
    , 28
    , 44
    , 255
    , 0
    , 32
    , 52
    , 255
    , 0
    , 37
    , 59
    , 255
    , 0
    , 42
    , 67
    , 255
    , 0
    , 48
    , 76
    , 255
    , 0
    , 53
    , 85
    , 255
    , 0
    , 60
    , 95
    , 255
    , 0
    , 66
    , 106
    , 255
    , 0
    , 73
    , 117
    , 255
    , 0
    , 80
    , 128
    , 255
    , 0
    , 88
    , 140
    , 255
    , 0
    , 95
    , 152
    , 255
    , 0
    , 104
    , 165
    , 255
    , 0
    , 112
    , 179
    , 255
    , 0
    , 121
    , 193
    , 255
    , 0
    , 130
    , 208
    , 255
    , 0
    , 140
    , 223
    , 255
    , 0
    , 149
    , 238
    , 255
    , 1
    , 160
    , 255
    , 255
    , 9
    , 163
    , 255
    , 255
    , 17
    , 166
    , 255
    , 255
    , 25
    , 169
    , 255
    , 255
    , 33
    , 172
    , 255
    , 255
    , 0
    , 0
    , 1
    , 2
    , 255
    , 0
    , 2
    , 4
    , 255
    , 0
    , 3
    , 6
    , 255
    , 0
    , 4
    , 9
    , 255
    , 0
    , 6
    , 13
    , 255
    , 0
    , 8
    , 16
    , 255
    , 0
    , 10
    , 21
    , 255
    , 0
    , 13
    , 26
    , 255
    , 0
    , 16
    , 32
    , 255
    , 0
    , 19
    , 38
    , 255
    , 0
    , 22
    , 44
    , 255
    , 0
    , 26
    , 52
    , 255
    , 0
    , 29
    , 59
    , 255
    , 0
    , 34
    , 67
    , 255
    , 0
    , 38
    , 76
    , 255
    , 0
    , 43
    , 85
    , 255
    , 0
    , 48
    , 95
    , 255
    , 0
    , 53
    , 106
    , 255
    , 0
    , 58
    , 117
    , 255
    , 0
    , 64
    , 128
    , 255
    , 0
    , 70
    , 140
    , 255
    , 0
    , 76
    , 152
    , 255
    , 0
    , 83
    , 165
    , 255
    , 0
    , 90
    , 179
    , 255
    , 0
    , 97
    , 193
    , 255
    , 0
    , 104
    , 208
    , 255
    , 0
    , 112
    , 223
    , 255
    , 0
    , 119
    , 238
    , 255
    , 1
    , 128
    , 255
    , 255
    , 9
    , 132
    , 255
    , 255
    , 17
    , 136
    , 255
    , 255
    , 25
    , 140
    , 255
    , 255
    , 0
    , 0
    , 0
    , 1
    , 255
    , 0
    , 0
    , 2
    , 255
    , 0
    , 1
    , 4
    , 255
    , 0
    , 2
    , 6
    , 255
    , 0
    , 3
    , 9
    , 255
    , 0
    , 4
    , 13
    , 255
    , 0
    , 6
    , 16
    , 255
    , 0
    , 8
    , 21
    , 255
    , 0
    , 9
    , 26
    , 255
    , 0
    , 12
    , 32
    , 255
    , 0
    , 14
    , 38
    , 255
    , 0
    , 16
    , 44
    , 255
    , 0
    , 19
    , 52
    , 255
    , 0
    , 22
    , 59
    , 255
    , 0
    , 25
    , 67
    , 255
    , 0
    , 28
    , 76
    , 255
    , 0
    , 32
    , 85
    , 255
    , 0
    , 36
    , 95
    , 255
    , 0
    , 39
    , 106
    , 255
    , 0
    , 44
    , 117
    , 255
    , 0
    , 48
    , 128
    , 255
    , 0
    , 52
    , 140
    , 255
    , 0
    , 57
    , 152
    , 255
    , 0
    , 62
    , 165
    , 255
    , 0
    , 67
    , 179
    , 255
    , 0
    , 72
    , 193
    , 255
    , 0
    , 78
    , 208
    , 255
    , 0
    , 84
    , 223
    , 255
    , 0
    , 89
    , 238
    , 255
    , 0
    , 96
    , 255
    , 255
    , 8
    , 101
    , 255
    , 255
    , 16
    , 106
    , 255
    , 255
    , 0
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 1
    , 255
    , 0
    , 0
    , 2
    , 255
    , 0
    , 1
    , 4
    , 255
    , 0
    , 1
    , 6
    , 255
    , 0
    , 2
    , 9
    , 255
    , 0
    , 3
    , 13
    , 255
    , 0
    , 4
    , 16
    , 255
    , 0
    , 5
    , 21
    , 255
    , 0
    , 6
    , 26
    , 255
    , 0
    , 8
    , 32
    , 255
    , 0
    , 9
    , 38
    , 255
    , 0
    , 11
    , 44
    , 255
    , 0
    , 13
    , 52
    , 255
    , 0
    , 14
    , 59
    , 255
    , 0
    , 17
    , 67
    , 255
    , 0
    , 19
    , 76
    , 255
    , 0
    , 21
    , 85
    , 255
    , 0
    , 24
    , 95
    , 255
    , 0
    , 26
    , 106
    , 255
    , 0
    , 29
    , 117
    , 255
    , 0
    , 32
    , 128
    , 255
    , 0
    , 35
    , 140
    , 255
    , 0
    , 38
    , 152
    , 255
    , 0
    , 41
    , 165
    , 255
    , 0
    , 45
    , 179
    , 255
    , 0
    , 48
    , 193
    , 255
    , 0
    , 52
    , 208
    , 255
    , 0
    , 56
    , 223
    , 255
    , 0
    , 59
    , 238
    , 255
    , 0
    , 64
    , 255
    , 255
    , 8
    , 70
    , 255
    , 255
    , 0
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 0
    , 255
    , 0
    , 0
    , 1
    , 255
    , 0
    , 0
    , 2
    , 255
    , 0
    , 0
    , 4
    , 255
    , 0
    , 0
    , 6
    , 255
    , 0
    , 1
    , 9
    , 255
    , 0
    , 1
    , 13
    , 255
    , 0
    , 2
    , 16
    , 255
    , 0
    , 2
    , 21
    , 255
    , 0
    , 3
    , 26
    , 255
    , 0
    , 4
    , 32
    , 255
    , 0
    , 4
    , 38
    , 255
    , 0
    , 5
    , 44
    , 255
    , 0
    , 6
    , 52
    , 255
    , 0
    , 7
    , 59
    , 255
    , 0
    , 8
    , 67
    , 255
    , 0
    , 9
    , 76
    , 255
    , 0
    , 10
    , 85
    , 255
    , 0
    , 12
    , 95
    , 255
    , 0
    , 13
    , 106
    , 255
    , 0
    , 14
    , 117
    , 255
    , 0
    , 16
    , 128
    , 255
    , 0
    , 17
    , 140
    , 255
    , 0
    , 19
    , 152
    , 255
    , 0
    , 20
    , 165
    , 255
    , 0
    , 22
    , 179
    , 255
    , 0
    , 24
    , 193
    , 255
    , 0
    , 26
    , 208
    , 255
    , 0
    , 28
    , 223
    , 255
    , 0
    , 29
    , 238
    , 255
    , 0
    , 32
    , 255
    , 255
    ]
